package process;

import java.util.logging.Level;

import org.compiere.model.MInfoColumn;
import org.compiere.model.MInfoWindow;
import org.compiere.model.PO;
import org.compiere.process.ProcessInfoParameter;
import org.compiere.process.SvrProcess;
import org.compiere.util.AdempiereSystemError;
import org.compiere.util.Msg;

public class CopyInfoWindowColumns extends SvrProcess {
	/** Target Info Window		*/
	private int		p_target_AD_InfoWindow_ID = 0;
	/** Source Info Window		*/
	private int		p_source_AD_InfoWindow_ID= 0;

	/** Column Count	*/
	private int 	m_count = 0;
	@Override
	protected void prepare() {
		ProcessInfoParameter[] para = getParameter();
		for (int i = 0; i < para.length; i++)
		{
			String name = para[i].getParameterName();
			if (para[i].getParameter() == null)
				;
			else if (name.equals("AD_InfoWindow_ID"))
				p_source_AD_InfoWindow_ID = para[i].getParameterAsInt();
			else
				log.log(Level.SEVERE, "Unknown Parameter: " + name);
		}
		p_target_AD_InfoWindow_ID = getRecord_ID();

	}

	@Override
	protected String doIt() throws Exception {
		if (p_target_AD_InfoWindow_ID == 0)
			throw new AdempiereSystemError("@NotFound@ @AD_InfoWindow_ID@ " + p_target_AD_InfoWindow_ID);
		if (p_source_AD_InfoWindow_ID == 0)
			throw new AdempiereSystemError("@NotFound@ @AD_InfoWindow_ID@ " + p_source_AD_InfoWindow_ID);
		if (log.isLoggable(Level.INFO)) log.info("Source AD_InfoWindow_ID=" + p_source_AD_InfoWindow_ID
				+ ", Target AD_InfoWindow_ID=" + p_target_AD_InfoWindow_ID);

		MInfoWindow targetInfoWindow = new MInfoWindow(getCtx(), p_target_AD_InfoWindow_ID, get_TrxName());
		MInfoColumn[] targetColumns = targetInfoWindow.getInfoColumns();
		if (targetColumns.length > 0) //Target Info Window must not have columns
			throw new AdempiereSystemError(Msg.getMsg(getCtx(), "must not have",new Object[] {targetInfoWindow.getName(), Msg.getElement(getCtx(),"AD_Column_ID")}));//{0} must not have {1}

		MInfoWindow sourceInfoWindow = new MInfoWindow(getCtx(), p_source_AD_InfoWindow_ID, get_TrxName());
		MInfoColumn[] sourceColumns = sourceInfoWindow.getInfoColumns();

		for (int i = 0; i < sourceColumns.length; i++)
		{
			MInfoColumn colTarget = new MInfoColumn(getCtx(),0, get_TrxName());
			PO.copyValues(sourceColumns[i], colTarget);
			colTarget.setAD_InfoWindow_ID (targetInfoWindow.getAD_InfoWindow_ID());
			colTarget.setAD_Org_ID(targetInfoWindow.getAD_Org_ID());
			colTarget.setEntityType(targetInfoWindow.getEntityType());
			colTarget.setIsActive(sourceColumns[i].isActive());
			colTarget.saveEx(get_TrxName());

			m_count++;
		}

		//
		return "#" + m_count;
	}

}
